@@ -128,16 +128,22 @@ class NotificationAdmin(admin.ModelAdmin):
     )
     ordering = ["-timestamp", "-notification_id"]
     list_filter = ("owner", RenderableNotificationFilter, "is_sent", "notif_type")
+    list_select_related = True
+
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.prefetch_related("owner__webhooks")
 
     def _webhooks(self, obj):
         if not obj.can_be_rendered:
             return format_html("<i>N/A</i>")
-        names = [
-            x.name
-            for x in obj.owner.webhooks.filter(
-                notification_types__contains=obj.notif_type
-            ).order_by("name")
-        ]
+        names = sorted(
+            [
+                webhook.name
+                for webhook in obj.owner.webhooks.all()
+                if obj.notif_type in webhook.notification_types
+            ]
+        )
         if names:
             return ", ".join(names)
         else:
@@ -263,7 +269,7 @@ class OwnerSyncStatusFilter(admin.SimpleListFilter):
 
 @admin.register(Owner)
 class OwnerAdmin(admin.ModelAdmin):
-    list_select_related = True
+    list_select_related = ("corporation", "corporation__alliance", "character")
     list_display = (
         "_corporation",
         "_alliance",
@@ -276,6 +282,7 @@ class OwnerAdmin(admin.ModelAdmin):
         "_is_structure_sync_ok",
         "_is_notification_sync_ok",
         "_is_forwarding_sync_ok",
+        "_is_asset_sync_ok",
         "_structures_count",
         "_notifications_count",
     )
@@ -289,6 +296,10 @@ class OwnerAdmin(admin.ModelAdmin):
     ordering = ["corporation__corporation_name"]
     search_fields = ["corporation__corporation_name"]
 
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.prefetch_related("ping_groups", "webhooks")
+
     def _has_default_pings_enabled(self, obj):
         return obj.has_default_pings_enabled
 
@@ -296,11 +307,7 @@ class OwnerAdmin(admin.ModelAdmin):
     _has_default_pings_enabled.boolean = True
 
     def _ping_groups(self, obj):
-        names = [x.name for x in obj.ping_groups.all().order_by("name")]
-        if names:
-            return names
-        else:
-            return None
+        return sorted([ping_group.name for ping_group in obj.ping_groups.all()])
 
     def _corporation(self, obj):
         return obj.corporation.corporation_name
@@ -316,7 +323,7 @@ class OwnerAdmin(admin.ModelAdmin):
     _alliance.admin_order_field = "corporation__alliance__alliance_name"
 
     def _webhooks(self, obj):
-        names = [x.name for x in obj.webhooks.all().order_by("name")]
+        names = sorted([webhook.name for webhook in obj.webhooks.all()])
         if names:
             return names
         else:
@@ -364,13 +371,22 @@ class OwnerAdmin(admin.ModelAdmin):
     _is_forwarding_sync_ok.boolean = True
     _is_forwarding_sync_ok.short_description = "forwarding"
 
+    def _is_asset_sync_ok(self, obj):
+        if not obj.is_active:
+            return None
+        else:
+            return obj.is_asset_sync_ok
+
+    _is_asset_sync_ok.boolean = True
+    _is_asset_sync_ok.short_description = "assets sync"
+
     def _notifications_count(self, obj: Owner) -> int:
-        return obj.notification_set.count()
+        return obj.notifications.count()
 
     _notifications_count.short_description = "notifications"
 
     def _structures_count(self, obj: Owner) -> int:
-        return obj.structure_set.count()
+        return obj.structures.count()
 
     _structures_count.short_description = "structures"
 
@@ -425,6 +441,8 @@ class OwnerAdmin(admin.ModelAdmin):
                 "structures_last_sync",
                 "forwarding_last_sync",
                 "forwarding_last_error",
+                "assets_last_sync",
+                "assets_last_error",
             )
         return self.readonly_fields
 
@@ -462,6 +480,10 @@ class OwnerAdmin(admin.ModelAdmin):
                         "forwarding_last_sync",
                         "forwarding_last_error",
                     ),
+                    (
+                        "assets_last_sync",
+                        "assets_last_error",
+                    ),
                 ),
             },
         ),
@@ -513,7 +535,7 @@ class OwnerCorporationsFilter(admin.SimpleListFilter):
 
     def lookups(self, request, model_admin):
         qs = (
-            EveCorporationInfo.objects.filter(owner__isnull=False)
+            EveCorporationInfo.objects.filter(structure_owner__isnull=False)
             .values("corporation_id", "corporation_name")
             .distinct()
             .order_by(Lower("corporation_name"))
@@ -535,7 +557,9 @@ class OwnerAllianceFilter(admin.SimpleListFilter):
 
     def lookups(self, request, model_admin):
         qs = (
-            EveAllianceInfo.objects.filter(evecorporationinfo__owner__isnull=False)
+            EveAllianceInfo.objects.filter(
+                evecorporationinfo__structure_owner__isnull=False
+            )
             .values("alliance_id", "alliance_name")
             .distinct()
             .order_by(Lower("alliance_name"))
@@ -552,7 +576,18 @@ class OwnerAllianceFilter(admin.SimpleListFilter):
 @admin.register(Structure)
 class StructureAdmin(admin.ModelAdmin):
     show_full_result_count = True
-    list_select_related = True
+    list_select_related = (
+        "owner",
+        "owner__corporation",
+        "owner__corporation__alliance",
+        "eve_solar_system",
+        "eve_solar_system__eve_constellation__eve_region",
+        "eve_type",
+        "eve_type__eve_group",
+        "eve_type__eve_group__eve_category",
+        "eve_planet",
+        "eve_moon",
+    )
     search_fields = [
         "name",
         "owner__corporation__corporation_name",
@@ -576,11 +611,16 @@ class StructureAdmin(admin.ModelAdmin):
 
     actions = ("add_default_tags", "remove_user_tags", "update_generated_tags")
 
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.prefetch_related("tags")
+
     def _owner(self, structure):
+        alliance = structure.owner.corporation.alliance
         return format_html(
             "{}<br>{}",
             structure.owner.corporation,
-            structure.owner.corporation.alliance,
+            alliance if alliance else "",
         )
 
     def _location(self, structure):
@@ -603,11 +643,7 @@ class StructureAdmin(admin.ModelAdmin):
         return structure.get_power_mode_display()
 
     def _tags(self, structure):
-        tag_names = [x.name for x in structure.tags.all()]
-        if tag_names:
-            return tag_names
-        else:
-            return None
+        return sorted([tag.name for tag in structure.tags.all()])
 
     _tags.short_description = "Tags"
 
@@ -665,8 +701,7 @@ class StructureAdmin(admin.ModelAdmin):
             [
                 x.name
                 for x in Structure._meta.get_fields()
-                if isinstance(x, models.fields.Field)
-                and x.name not in ["tags", "last_online_at"]
+                if isinstance(x, models.fields.Field) and x.name not in ["tags"]
             ]
         )
 
@@ -685,6 +720,8 @@ class StructureAdmin(admin.ModelAdmin):
                     "unanchors_at",
                     "fuel_expires_at",
                     "last_online_at",
+                    "has_fitting",
+                    "has_core",
                 ),
             },
         ),
@@ -738,6 +775,7 @@ class WebhookAdmin(admin.ModelAdmin):
     list_display = (
         "name",
         "_ping_groups",
+        "_owners",
         "is_active",
         "_is_default",
         "_messages_in_queue",
@@ -745,17 +783,22 @@ class WebhookAdmin(admin.ModelAdmin):
     list_filter = ("is_active",)
     save_as = True
 
+    def get_queryset(self, request):
+        qs = super().get_queryset(request)
+        return qs.prefetch_related("ping_groups", "owner_set", "owner_set__corporation")
+
     def _default_pings(self, obj):
         return obj.has_default_pings_enabled
 
     _default_pings.boolean = True
 
     def _ping_groups(self, obj):
-        names = [x.name for x in obj.ping_groups.all().order_by("name")]
-        if names:
-            return names
-        else:
-            return None
+        return sorted([ping_group.name for ping_group in obj.ping_groups.all()])
+
+    def _owners(self, obj):
+        return sorted([str(owner) for owner in obj.owner_set.all()])
+
+    _owners.short_description = "Enabled for Owners"
 
     def _is_default(self, obj):
         value = True if obj.is_default else None
