@@ -1,6 +1,5 @@
 """Notification related models"""
 
-import logging
 from typing import Tuple
 
 import dhooks_lite
@@ -18,6 +17,7 @@ from django.utils.translation import gettext_lazy as _
 from esi.models import Token
 
 from allianceauth.eveonline.evelinks import dotlan, eveimageserver
+from allianceauth.services.hooks import get_extension_logger
 from app_utils.datetime import (
     DATETIME_FORMAT,
     ldap_time_2_datetime,
@@ -27,7 +27,7 @@ from app_utils.django import app_labels
 from app_utils.logging import LoggerAddTag
 from app_utils.urls import static_file_absolute_url
 
-from .. import __title__
+from .. import __title__, constants
 from ..app_settings import (
     STRUCTURES_DEFAULT_LANGUAGE,
     STRUCTURES_MOON_EXTRACTION_TIMERS_ENABLED,
@@ -37,7 +37,7 @@ from ..app_settings import (
 )
 from ..managers import EveEntityManager, NotificationManager
 from ..webhooks.models import WebhookBase
-from .eveuniverse import EveMoon, EvePlanet, EveSolarSystem, EveType
+from .eveuniverse import EveMoon, EvePlanet, EveSolarSystem
 from .structures import Structure
 
 if "timerboard" in app_labels():
@@ -57,7 +57,7 @@ if "structuretimers" in app_labels():
 else:
     has_structure_timers = False
 
-logger = LoggerAddTag(logging.getLogger(__name__), __title__)
+logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 # Supported languages
 LANGUAGES = (
@@ -238,30 +238,6 @@ class NotificationType(models.TextChoices):
         ]
 
 
-# def choices_subset(*notification_types):
-#     return tuple([(item.value, item.label) for item in notification_types])
-
-
-# NOTIFICATION_CHOICES = (
-#     (
-#         _("Corporation Member"),
-#         choices_subset(
-#             NotificationType.CHAR_APP_ACCEPT_MSG, NotificationType.CHAR_LEFT_CORP_MSG
-#         ),
-#     ),
-#     (
-#         _("Moonmining"),
-#         choices_subset(
-#             NotificationType.MOONMINING_EXTRACTION_STARTED,
-#             NotificationType.MOONMINING_EXTRACTION_CANCELLED,
-#             NotificationType.MOONMINING_LASER_FIRED,
-#             NotificationType.MOONMINING_EXTRACTION_FINISHED,
-#             NotificationType.MOONMINING_AUTOMATIC_FRACTURE,
-#         ),
-#     ),
-# )
-
-
 def get_default_notification_types():
     """DEPRECATED: generates a set of all existing notification types as default-"""
     return tuple(sorted([str(x[0]) for x in NotificationType.values]))
@@ -379,15 +355,20 @@ class Notification(models.Model):
 
     # event type structure map
     MAP_CAMPAIGN_EVENT_2_TYPE_ID = {
-        1: EveType.EVE_TYPE_ID_TCU,
-        2: EveType.EVE_TYPE_ID_IHUB,
+        1: constants.EVE_TYPE_ID_TCU,
+        2: constants.EVE_TYPE_ID_IHUB,
+    }
+    MAP_TYPE_ID_2_TIMER_STRUCTURE_NAME = {
+        constants.EVE_TYPE_ID_POCO: "POCO",
+        constants.EVE_TYPE_ID_TCU: "TCU",
+        constants.EVE_TYPE_ID_IHUB: "I-HUB",
     }
-    MAP_TYPE_ID_2_TIMER_STRUCTURE_NAME = {2233: "POCO", 32226: "TCU", 32458: "I-HUB"}
 
     notification_id = models.PositiveBigIntegerField(verbose_name="id")
     owner = models.ForeignKey(
         "Owner",
         on_delete=models.CASCADE,
+        related_name="notifications",
         help_text="Corporation that received this notification",
     )
     sender = models.ForeignKey(EveEntity, on_delete=models.CASCADE)
@@ -553,7 +534,7 @@ class Notification(models.Model):
     def _gen_avatar(self) -> Tuple[str, str]:
         if STRUCTURES_NOTIFICATION_SET_AVATAR:
             username = "Notifications"
-            avatar_url = static_file_absolute_url("structures/structures_logo.png")
+            avatar_url = static_file_absolute_url("structures/img/structures_logo.png")
         else:
             username = None
             avatar_url = None
@@ -785,7 +766,7 @@ class Notification(models.Model):
                 id=parsed_text["solarSystemID"]
             )
             structure_type, _ = EveType2.objects.get_or_create_esi(
-                id=EveType.EVE_TYPE_ID_POCO
+                id=constants.EVE_TYPE_ID_POCO
             )
             visibility = (
                 Timer.VISIBILITY_CORPORATION
