@@ -1,7 +1,6 @@
 """Owner related models"""
 
 import json
-import logging
 import math
 import os
 import re
@@ -21,11 +20,12 @@ from esi.models import Token
 from allianceauth.authentication.models import CharacterOwnership
 from allianceauth.eveonline.models import EveCorporationInfo
 from allianceauth.notifications import notify
+from allianceauth.services.hooks import get_extension_logger
 from app_utils.datetime import DATETIME_FORMAT
 from app_utils.helpers import chunks
 from app_utils.logging import LoggerAddTag, make_logger_prefix
 
-from .. import __title__
+from .. import __title__, constants
 from ..app_settings import (
     STRUCTURES_ADD_TIMERS,
     STRUCTURES_DEFAULT_LANGUAGE,
@@ -39,18 +39,12 @@ from ..app_settings import (
     STRUCTURES_STRUCTURE_SYNC_GRACE_MINUTES,
 )
 from ..helpers.esi_fetch import esi_fetch, esi_fetch_with_localization
-from .eveuniverse import (
-    EveGroup,
-    EveMoon,
-    EvePlanet,
-    EveSolarSystem,
-    EveType,
-    EveUniverse,
-)
+from ..managers import OwnerAssetManager
+from .eveuniverse import EveMoon, EvePlanet, EveSolarSystem, EveType, EveUniverse
 from .notifications import EveEntity, Notification, NotificationType
 from .structures import Structure
 
-logger = LoggerAddTag(logging.getLogger(__name__), __title__)
+logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
 class General(models.Model):
@@ -69,6 +63,7 @@ class General(models.Model):
                 "view_all_unanchoring_status",
                 "Can view unanchoring timers for all structures the user can see",
             ),
+            ("view_structure_fit", "Can view structure fit"),
         )
 
 
@@ -103,6 +98,7 @@ class Owner(models.Model):
         EveCorporationInfo,
         primary_key=True,
         on_delete=models.CASCADE,
+        related_name="structure_owner",
         help_text="Corporation owning structures",
     )
     character = models.ForeignKey(
@@ -111,6 +107,7 @@ class Owner(models.Model):
         default=None,
         null=True,
         blank=True,
+        related_name="+",
         help_text="character used for syncing structures",
     )
     structures_last_sync = models.DateTimeField(
@@ -121,6 +118,14 @@ class Owner(models.Model):
         default=ERROR_NONE,
         help_text="error that occurred at the last sync atttempt (if any)",
     )
+    assets_last_sync = models.DateTimeField(
+        null=True, default=None, blank=True, help_text="when the last sync happened"
+    )
+    assets_last_error = models.IntegerField(
+        choices=ERRORS_LIST,
+        default=ERROR_NONE,
+        help_text="error that occurred at the last sync atttempt (if any)",
+    )
     notifications_last_sync = models.DateTimeField(
         null=True, default=None, blank=True, help_text="when the last sync happened"
     )
@@ -219,6 +224,18 @@ class Owner(models.Model):
             > (now() - timedelta(minutes=STRUCTURES_FORWARDING_SYNC_GRACE_MINUTES))
         )
 
+    @property
+    def is_asset_sync_ok(self) -> bool:
+        """returns true if they have been no errors
+        and last syncing occurred within alloted time
+        """
+        return (
+            self.assets_last_error == self.ERROR_NONE
+            and self.assets_last_sync
+            and self.assets_last_sync
+            > (now() - timedelta(minutes=STRUCTURES_STRUCTURE_SYNC_GRACE_MINUTES))
+        )
+
     @property
     def are_all_syncs_ok(self) -> bool:
         """returns true if they have been no errors
@@ -321,7 +338,7 @@ class Owner(models.Model):
 
         if user:
             self._send_report_to_user(
-                "structures", self.structure_set.count(), success, error_code, user
+                "structures", self.structures.count(), success, error_code, user
             )
 
         return success
@@ -495,7 +512,7 @@ class Owner(models.Model):
                     reinforce_hour = reinforce_exit_start + timedelta(hours=1)
                     structure = {
                         "structure_id": office_id,
-                        "type_id": EveType.EVE_TYPE_ID_POCO,
+                        "type_id": constants.EVE_TYPE_ID_POCO,
                         "corporation_id": corporation_id,
                         "name": name if name else "",
                         "system_id": poco["system_id"],
@@ -806,7 +823,7 @@ class Owner(models.Model):
         """
         # identify new notifications
         existing_notification_ids = set(
-            self.notification_set.values_list("notification_id", flat=True)
+            self.notifications.values_list("notification_id", flat=True)
         )
         new_notifications = [
             obj
@@ -875,7 +892,7 @@ class Owner(models.Model):
         """processes notifications for timers if any"""
         empty_refineries = Structure.objects.filter(
             owner=self,
-            eve_type__eve_group_id=EveGroup.EVE_GROUP_ID_REFINERY,
+            eve_type__eve_group_id=constants.EVE_GROUP_ID_REFINERY,
             eve_moon__isnull=True,
         )
         if empty_refineries:
@@ -1094,3 +1111,76 @@ class Owner(models.Model):
             "{}_raw_{}.json".format(name, corporation_id), "w", encoding="utf-8"
         ) as f:
             json.dump(data, f, cls=DjangoJSONEncoder, sort_keys=True, indent=4)
+
+    def update_asset_esi(self, user: User = None):
+        """Update all assets for owner where location_id is in the active structure list from esi"""
+        add_prefix = self._logger_prefix()
+        try:
+            token, error = self.token()
+            if error:
+                self.assets_last_error = error
+                self.assets_last_sync = now()
+                self.save()
+                raise TokenError(self.to_friendly_error_message(error))
+
+            try:
+                structure_ids = {x.id for x in Structure.objects.filter(owner=self)}
+                OwnerAsset.objects.update_or_create_for_structures_esi(
+                    structure_ids, self.corporation.corporation_id, token
+                )
+            except Exception as ex:
+                logger.exception(
+                    add_prefix("An unexpected error ocurred {}".format(ex))
+                )
+                self.assets_last_error = self.ERROR_UNKNOWN
+                self.assets_last_sync = now()
+                self.save()
+                raise ex
+        except Exception as ex:
+            success = False
+            error_code = str(ex)
+        else:
+            success = True
+            error_code = None
+            self.assets_last_error = self.ERROR_NONE
+            self.assets_last_sync = now()
+            self.save()
+
+        if user:
+            self._send_report_to_user(
+                "assets", self.structures.count(), success, error_code, user
+            )
+
+
+class OwnerAsset(models.Model):
+    """An asset for a corporation"""
+
+    id = models.BigIntegerField(primary_key=True, help_text="The Item ID of the assets")
+    eve_type = models.ForeignKey(
+        "EveType",
+        on_delete=models.CASCADE,
+        help_text="type of the assets",
+        related_name="+",
+    )
+    owner = models.ForeignKey(
+        "Owner",
+        on_delete=models.CASCADE,
+        related_name="assets",
+        help_text="Corporation that owns the assets",
+    )
+    is_singleton = models.BooleanField(null=False)
+    location_flag = models.CharField(max_length=255)
+    location_id = models.BigIntegerField(null=False, db_index=True)
+    location_type = models.CharField(max_length=255)
+    quantity = models.IntegerField(null=False)
+    last_updated_at = models.DateTimeField(auto_now=True)
+
+    objects = OwnerAssetManager()
+
+    def __str__(self) -> str:
+        return str(self.eve_type.name)
+
+    def __repr__(self):
+        return "{}(pk={}, owner=<{}>, eve_type=<{}>)".format(
+            self.__class__.__name__, self.pk, self.owner, self.eve_type
+        )
