@@ -29,6 +29,7 @@ from app_utils.views import (
     link_html,
     no_wrap_html,
     yesno_str,
+    yesnonone_str,
 )
 
 from . import __title__, constants, tasks
@@ -375,19 +376,23 @@ class StructuresRowBuilder:
             )
 
     def _build_core_status(self):
-        """Only enable view core for structure types"""
         if self._structure.eve_type.is_upwell_structure:
             if self._structure.has_core is True:
+                has_core = True
                 core_status = '<i class="fas fa-check" title="Core present"></i>'
             elif self._structure.has_core is False:
+                has_core = False
                 core_status = (
                     '<i class="fas fa-times text-danger title="Core absent"></i>'
                 )
             else:
+                has_core = None
                 core_status = '<i class="fas fa-question" title="Status unknown"></i>'
         else:
+            has_core = None
             core_status = "-"
         self._row["core_status"] = core_status
+        self._row["core_status_str"] = yesnonone_str(has_core)
 
     def _build_view_fit(self):
         """Only enable view fit for structure types"""
@@ -395,7 +400,7 @@ class StructuresRowBuilder:
             "structures.view_structure_fit"
         ):
             ajax_structure_fit = reverse(
-                "structures:structure_fit",
+                "structures:structure_details",
                 args=[self._row["structure_id"]],
             )
             self._row["view_fit"] = format_html(
@@ -471,7 +476,7 @@ def _structures_query_for_user(request):
 
 @login_required
 @permission_required("structures.view_structure_fit")
-def structure_fit(request, structure_id):
+def structure_details(request, structure_id):
     """Main view of the structure fit"""
 
     class Slot(IntEnum):
@@ -493,7 +498,7 @@ def structure_fit(request, structure_id):
             try:
                 slot_num = type_attributes[self.value]
                 return staticfiles_storage.url(
-                    f"/structures/img/pannel/{slot_num}{id_map[self.value]}.png"
+                    f"structures/img/pannel/{slot_num}{id_map[self.value]}.png"
                 )
             except KeyError:
                 return ""
@@ -528,31 +533,30 @@ def structure_fit(request, structure_id):
         "rig": Slot.RIG.image_url(),
         "service": Slot.SERVICE.image_url(),
     }
-    fit_ob = {"Cargo": [], "FighterBay": [], "StructureFuel": []}
-    fittings = OwnerAsset.objects.select_related("eve_type").filter(
+    assets = OwnerAsset.objects.select_related("eve_type").filter(
         location_id=structure_id
     )
-    high_slots = extract_slot_assets(fittings, "HiSlot")
-    med_slots = extract_slot_assets(fittings, "MedSlot")
-    low_slots = extract_slot_assets(fittings, "LoSlot")
-    rig_slots = extract_slot_assets(fittings, "RigSlot")
-    service_slots = extract_slot_assets(fittings, "ServiceSlot")
-    fighter_tubes = extract_slot_assets(fittings, "FighterTube")
-    for fi in fittings:
-        if fi.location_flag == "Cargo":
-            fit_ob["Cargo"].append(fi)
-        elif fi.location_flag == "FighterBay":
-            fit_ob["FighterBay"].append(fi)
-        elif fi.location_flag == "StructureFuel":
-            fit_ob["StructureFuel"].append(fi)
+    high_slots = extract_slot_assets(assets, "HiSlot")
+    med_slots = extract_slot_assets(assets, "MedSlot")
+    low_slots = extract_slot_assets(assets, "LoSlot")
+    rig_slots = extract_slot_assets(assets, "RigSlot")
+    service_slots = extract_slot_assets(assets, "ServiceSlot")
+    fighter_tubes = extract_slot_assets(assets, "FighterTube")
+    assets_grouped = {"ammo_hold": [], "fighter_bay": [], "fuel_bay": []}
+    for asset in assets:
+        if asset.location_flag == "Cargo":
+            assets_grouped["ammo_hold"].append(asset)
+        elif asset.location_flag == "FighterBay":
+            assets_grouped["fighter_bay"].append(asset)
+        elif asset.location_flag == "StructureFuel":
+            assets_grouped["fuel_bay"].append(asset)
         else:
-            fit_ob[fi.location_flag] = fi
+            assets_grouped[asset.location_flag] = asset
 
     context = {
-        "page_title": gettext_lazy(__title__),
+        "fitting": assets,
         "slots": slot_image_urls,
-        "fitting": fit_ob,
-        "assets": {
+        "slot_assets": {
             "high_slots": high_slots,
             "med_slots": med_slots,
             "low_slots": low_slots,
@@ -560,10 +564,11 @@ def structure_fit(request, structure_id):
             "service_slots": service_slots,
             "fighter_tubes": fighter_tubes,
         },
+        "assets_grouped": assets_grouped,
         "structure": structure,
         "last_updated": structure.owner.assets_last_sync,
     }
-    return render(request, "structures/modals/structure_fit.html", context)
+    return render(request, "structures/modals/structure_details.html", context)
 
 
 @login_required
